|pytest CI| |Documentation Status| |codecov| |pre-commit|

This library provides a set of tools to approximate data grids, either via interpolation or regression. This project aims
to provide an uniform and fast workflow for tensor operations while maintaining the accuracy and precision on the approximation.

Installation
============

The library can be installed directly from its PyPi_ project page running the command:

``pip install innate-stable``

Development
===========

INNATE is currently on an alpha release. Any comment/issue/request can be added as an issue on the github page.
Please commit to dev branch.

.. _PyPi: https://pypi.org/project/innate-stable/
.. _github: https://github.com/Vital-Fernandez/innate

.. image:: https://github.com/Vital-Fernandez/innate/blob/master/docs/source/_static/Logo1.png?raw=true
    :width: 30%
    :align: center
    :alt: INNATE library logo.

.. |Documentation Status| image:: https://readthedocs.org/projects/innate/badge/?version=latest
   :target: https://innate.readthedocs.io/?badge=latest

.. |pytest CI| image:: https://github.com/Vital-Fernandez/innate/actions/workflows/pytest.yml/badge.svg?event=push
   :target: https://github.com/Vital-Fernandez/innate/actions/workflows/pytest.yml

.. |pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit
   :target: https://github.com/pre-commit/pre-commit

.. |codecov| image:: https://codecov.io/gh/Vital-Fernandez/innate/branch/master/graph/badge.svg 
   :target: https://codecov.io/gh/Vital-Fernandez/innate
